#
# spec file for package QtPass
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           QtPass
Version:        1.4.0
Release:        1.4
Summary:        A multi-platform gui for pass
License:        GPL-3.0-only
Group:          Productivity/Security
URL:            https://qtpass.org/
Source0:        https://github.com/IJHack/qtpass/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.10.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       password-store
Recommends:     git-core
Recommends:     gpg2
Recommends:     pwgen
Provides:       qtpass

%description
QtPass is a multi-platform GUI for pass, the standard unix password manager.

%prep
%autosetup

%build
export QT_HASH_SEED=0
%qmake5 PREFIX=%{_prefix}
%make_jobs

%install
%qmake5_install
%suse_update_desktop_file -i qtpass
install -Dpm644 artwork/icon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/qtpass-icon.svg
install -Dpm644 qtpass.appdata.xml %{buildroot}%{_datadir}/appdata/qtpass.appdata.xml
install -Dpm644 qtpass.1 %{buildroot}%{_mandir}/man1/qtpass.1

# do not ship tests
rm -rf %{buildroot}%{_prefix}%{_prefix}/tests

%files
%license LICENSE
%doc README.md
%{_bindir}/qtpass
%{_datadir}/applications/qtpass.desktop
%{_datadir}/appdata/qtpass.appdata.xml
%{_datadir}/icons/hicolor/scalable/apps/qtpass-icon.svg
%{_mandir}/man1/qtpass.1%{?ext_man}

%changelog
* Tue Sep 19 2023 ecsos <ecsos@opensuse.org>
- Update to 1.4.0
  * What's Changed
  - Don't use a deprecated method in #491
  - Issue #402: 'deselect()' on clearing filter in #490
  - Don't base pass-otp availability decision on hardcoded /usr/lib in #499
  - Use new stable version of install-qt-action.  in #502
  - Enable out-of-source build in #503
  - Enable ubuntu, windows and macOS based builds for CI in #508
  - Spelling: Git pull, Git push in #516
  - Fix blurry icons when fractional scaling is enabled in #526
  - Update minimum Qt version in #527
  - #514 Show password with a monospace font in #528
  - Clear search on profile change in #529
  - Move MainWindow to the screen the cursor is on in #547
  - Fix issues with renaming passwords and moving folders in #532
  - Explicitly only remove ".gpg" when renaming files in #558
  - Keep suffices when moving (to) a directory while imitiating pass in #559
  - Fix keys created/expires dates in the users dialog window (fix: 571) in #572
  - Fix installation instructions in README.md in #565
  - Delete context menu after exec in #578
  - Add more options for the password displaying in #587
  - Fix accidental deletion of entire passwordstore in #604
  - Install QT in codeql workflow in #608
  - Super Linter added and fixing findings in #610
  - Removed travis (no longer free) and lgtm (migrated to Github) in #612
  - fix the unintended "running" of the entropy window in the keygen dial… in #640
  - Restore licensing info for QProgressIndicator in #642
  - Add pass store signing key feature in #634
  - Fix taborder and add buddies in keygen dialog in #643
  - Clazy cleanup and other minor fixes in #641
  - fix bug => clipboard was not cleared when using primary selection in #615
  - super-linter ENV variables in shared location for local and automated in #616
  - clang-format -i src/.cpp src/.h in #645
  - Version bump and cleanup in #646
  * Wording and localisation
  - Spelling: Git, GPG, PWGen, etc. in #492
  - Spelling: Keylist missing, Could not fetch, GPG in #493
  - Spelling: Search for users, , in #495
  - Translations update from Weblate in #530
  - Translations update from Weblate in #531
  - Translations update from Weblate in #535
  - Translations update from Weblate in #541
  - Translations update from Weblate in #548
  - Translations update from Weblate in #552
  - Translations update from Weblate in #553
  - Translations update from Weblate in #554
  - Translations update from Weblate in #560
  - Translations update from Weblate in #562
  - Translations update from Weblate in #563
  - Correct a typo in pass.cpp in #570
  - Translations update from Weblate in #573
  - Translations update from Hosted Weblate in #576
  - Translations updated in #605
  - Translation cleanup in #606
  - Translations update from Hosted Weblate in #607
  - New Transifex integration yml in #609
  - Translations update from Hosted Weblate in #611
  - Translations update from Hosted Weblate in #613
  - Translations update from Hosted Weblate in #614
  - Translations update from Hosted Weblate in #617
  - Translations update from Hosted Weblate in #618
  - Document "Using profiles" in #619
  - markdownlint --fix && textlint --fix in #621
  - Translations update from Hosted Weblate in #622
  - Translations update from Hosted Weblate in #626
  - Translations update from Hosted Weblate in #627
  - Translations update from Hosted Weblate in #628
  - Translations update from Hosted Weblate in #629
  - Translations update from Hosted Weblate in #632
  - Translations update from Hosted Weblate in #633
  - Translations update from Hosted Weblate in #636
  - Translations update from Hosted Weblate in #644
  - Translations update from Hosted Weblate in #647
  - Translations update from Hosted Weblate in #648
  - Added Serbian and Estonian to project file in #649
  - Translations update from Hosted Weblate in #650
  - Natural language fixes in #654
  - Initial Korean from Weblate in #655
* Sun Apr 12 2020 ecsos@opensuse.org
- Add qtpass.appdata.xml.
* Wed Oct  9 2019 ecsos@opensuse.org
- Update to 1.3.2
  - Don't call QtPass::setup() from QtPass class constructor #482
    fixes first run issues #485, #481, #466, #423 and #308
  - Password window padding #484
  - Buttons width on RHEL 8 #483
  - Start minimized works again #471
* Sun Oct  6 2019 ecsos@opensuse.org
- Rename all to package_naming_guidelines.
* Sat Oct  5 2019 Martin Hauke <mardnh@gmx.de>
- Remove superfluous entry for password-store from Recommends as
  it's already stated in Requires
- Add hicolor-icon-theme to BuildRequires
* Wed Oct  2 2019 ecsos@opensuse.org
- Update to 1.3.1
  - Renaming password #463 #469
  - Edit main title field #446
  - Add missing finishedShow() signal connection in PasswordDialog
    constructor (fixes the "Edit password" function) #473
  - Build dependency fixes #467 #479
  - Additional lines (notes) shown again #474
  - Running but no GUI #451
  - Correct font color with Dark themes #340 #476
  - Add missing overrides #478
  - Sorted profiles dropdown as in #404 #472
  - Fix missing app ID and icon on Wayland. #468
* Sat Aug 24 2019 ecsos@opensuse.org
- Update to 1.3.0
  Some of the many changes, please resort to the CHANGELOG for
  a more complete listing.
  - Add otp (two factor authentication) support #327
  - Use key fingerprint as ID instead of “long” ID. #452
  - Typo: dialouge to dialogue. #444
  - Scripts and logic specific to Windows Store releases #439
  - For config check, check that the selected binary is available.
    [#438]
  - Fix character encoding issues for non-UTF-8 locales. #435
  - Fixes and improvments for config dialog #432
  - Support for using WSL binaries on Windows #431
  - Bugfixes and Windows compatibility improvements #430
  - Semi-automatic code cleanup #425
  - Update to prevent the installer requesting admin #424
  - Display passwords as QR codes #421
  - Tested working on Mac Os HS with pinentry-mac #419
  - Bugfixes #413
  - pwgen: fix inverted "Generate ... less secure passwords"
    checkbox #409
  - Continuing refactoring #407
  - #390 make box cheched when opening a folder users panel #403
  - Windows sigsev issues #326
  - Access to the / (root) directory form within the application
    window on MacOS #302
  - Context menu on transparent fields is transparent too . . #227
  - Various issues with Info.plist file on macOS #457
  - Problem with GNUpg not found on MacOS #362
  - Unable to see main application window (applicationn runs
    minimized to tray only) #286
* Sat Oct 13 2018 Herbert Graeber <herbert@graeber-clan.de>
- For reprodicibilty QT_HASH_SEED has to be set to 0
* Mon Jul  9 2018 herbert@graeber-clan.de
- Make RCC calls reproducible
* Tue Jun  5 2018 ecsos@opensuse.org
- update to 1.2.3
  - Add support for OTP code generation on Linux as requested in
    [#327] #394 (Noettore)
  - Revert scroll bar changes #393 (destanyol)
  - Fix High Dpi Support. Works now under Windows and KDE/Plasma.
    [#392] (hgraeber)
  - Duplicate prefix in installation of tests directory in v1.2.2.
    [#389]
  - Compilation error on FreeBSD member access into incomplete type
    [#388]
- remove patch qtpass-highdpi.patch because now in upstream
* Wed May  9 2018 herbert@graeber-clan.de
- Remove the qtpass-highdpi.patch, merged upstream
* Wed May  9 2018 ecsos@opensuse.org
- update to 1.2.2
  - Clipboard clearing timer is not reset when new passwords are
    copied to the clipboard #309
  - Removal of files outside of password-store #300 #363
  - Lots of fixes and refactoring. #364 #376 #378 #381 #382 #384
    [#386]
  - Fix & make clearClipboard more robust #359
  - Multiple question marks while trying to delete password #385
  - No button icons and text in "menu bar" #383
  - Entire program is huge on High DPI screen on Linux #369
  - Parallel make issue in qtpass-1.2.1: ld: cannot find -lqtpass
    [#350]
  - No password entry prompt #343
  - Can't install on OS X Sierra #337
  - No icon on MacOS #333
  - Font and spacing used for URL links on right in main window
    absurdly large #329
  - QtPass don't display all lines with templates #273 #358
  - Update CONTRIBUTING.md #354 and add two entries in FAQ about
    the language #353
  - Fix nested template argument list compile error #346
  - Honor PREFIX during tests install #345
* Wed Feb 28 2018 herbert@graeber-clan.de
- Convert to license to SPDX-3.0
- Use %%license
* Thu Jan  4 2018 avindra@opensuse.org
- update to 1.2.1
  * All passwords that have been generated with QtPass prior to
    1.2.1 should be regenerated and changed.
  * Version 1.2.0 leaks passwords
  * When importing settings from 1.1.5 or older, clipboard
    settings revert to No Clipboard
  * Add Catalan translation
* Wed Nov 15 2017 herbert@graeber-clan.de
- Fix HighDPI
* Thu Nov  9 2017 aavindraa@gmail.com
- update to 1.2.0
  * Many UX improvements
  * Improved process management
  * Extraction of library and main function
  * Added sftp, ftps, webdav and webdavs as supported links
  * PRNG issues on Windows fixed
- cleanup spec file with spec-cleaner
* Sun Feb 26 2017 herbert@graeber-clan.de
- Install rudimentary manual page provided as part of the tarball
* Sun Feb 26 2017 herbert@graeber-clan.de
- Cleanup recommends
  * Add recommend for password-store, but leave the recommends for
    gpg2 and pwgen for the case password-store is not installed
  * Recommend git-core instead of git, because the latter pulls
    other unneeded packages like git-cvs and git-svn
* Sun Feb 26 2017 herbert@graeber-clan.de
- Switch to Qt5
* Fri Dec  2 2016 mardnh@gmx.de
- update to 1.1.6
  - Better seeder for qrand() as noted in #238 this is not a proper
  fix. Use of the build-in fallback password generator is
  discouraged.
  - Short fullname would hang QtPass keypair generation process for
  infinite time #202
  - keygendialog email and name validition (issue 202) #203
  - Lookup validity field to check if keys are valid #201
  - view box is trimming whitespace #210
  - QtPass starts by searching for -psn_0_12345 on macOS #213
  - Allow ssh links #211
  - Increase maximum password length to 255 #209
  - Updated German Translation #206
  - Better seeder for qrand() as noted in #238
  - Italian translation #204
  - Translated for Simplified Chinese. #208
* Thu Oct 20 2016 ecsos@opensuse.org
- update to 1.1.5
  - Allow ssh:// links #211
  - View box no longer trims whitespace #210
  - Increase maximum password length to 255 #209
  - Full translation to Simplified Chinese. #208
  - Password generation options and templates #207 #98
  - Updated German Translation #206
  - Italian translation #204
  - KeygenDialog email and name validation #202 #203
  - Lookup validity field to check if keys are valid #201
  - Fixed a spelling error #200
  - Windows build with Qt 5.7 (almost half the size now)
* Tue Sep 27 2016 ecsos@opensuse.org
- update to 1.1.4
  - PREFIX is now really a prefix #185
  - Encoding issues #192, #131, #101 and #91 fixed in #198 and #199
  - Re-assign permissions when adding users #161
  - French translations
    https://www.transifex.com/ijhack/qtpass/
  - Completed Dutch and German translations
* Sat Jun 11 2016 ecsos@opensuse.org
- update to 1.1.3
  - Clipboard now cleared when quitting or killing application #171
  - Wait till processes done on edit #177
  - Hide content now works when using templates #160
  - Added warning started work on #161 #150
- changes from 1.1.2
  - Fix build issues with MSVC2015 on Windows #175
  - Deletion of empty folders when using git fixed #181
  - Trimming of values in templates #182
  - Updated translations, completed Dutch and German
* Tue Apr  5 2016 ecsos@opensuse.org
- update to 1.1.1
  - Same name for file and folder #159 (fixed up-stream)
  - Use --secure for pwgen and more configurable options #168
  - Some UI tweaks #158
  - Some translation updates #162
  - Remove Debian packaging #166
  - Clear text input: use system icon instead of x #84
  - Bind a key to the clear action #142
  - Flat icon bd742d6 for more modern look
  - Minor cleanup and FAQ changes
* Sun Feb 21 2016 mardnh@gmx.de
- install desktop file and icon
* Fri Jan 29 2016 ecsos@opensuse.org
- update to 1.1.0
  - Fixed qrand initialisation (used to generate predictable
    passwords) #129
  - System Icons on Buttons #124
  - Doubleclick on treeView #124
  - Updated config layout #124
  - Good (fallback) icons #143
  - Translation fixes and additions
* Sun Jan  3 2016 mardnh@gmx.de
- update to 1.0.6
  - Updated german translation #125 #126 #134
  - Fixed qrand always generating the same sequence of passwords
    [#129]
  - Fixed deleted record can be retrieved bug #117
  - On-demand copy to clipboard feature #119
  - Always on top feature #118
  - Fixed timer issue #122 (introduced in #119)
- use proper CXXFLAGS
- ran spec-cleaner
* Thu Nov 19 2015 ecsos@opensuse.org
- update to 1.0.5
  - Auto hiding of content doesn't need clipboard 76dacca
  - Auto content hiding timer gets stopped when starting new task
    1fa596d a8fa7b2
  - Remove template widgets when starting new task 4e7ac13
  - Using pwgen won't add a carriage return to password anymore
    [#115]
  - Output of git commands won't (always) show in red anymore #111
  - Tab order of templated fields is correctly set 2f9c6f7
  - SingleApplication communication problem workaround 3fc1dc7
  - Translation building system updated and further removal of
    duplicate and unneeded bits
  - Use example template format from passff as default 107dbff
    5ec97c7
  - CI building windows installer
    https://ci.appveyor.com/project/annejan/qtpass/build/artifacts
* Thu Nov  5 2015 ecsos@opensuse.org
- update to 1.0.4
  - Support for RightToLeft languages #108
  - FreeBSD fixes 2ed0093 7c26329
  - Windows "hidden" folder fix #63
  - Minor cleanup work 4302cc0 f6d68f4 8b6a533
  - Some work on the language creation/update mechanics 741c4b7 and
    other minor tweaks.
* Sun Oct 25 2015 ecsos@opensuse.org
- update to 1.0.3
  - Spanish translations added #103
  - Use pass show password instead of unsafe fallback
    pass password #105
  - Get PREFIX variable from qmake or env #106
  - Templating skips parsing colon in urls unless specifically
    added prefix to template.
* Fri Sep 25 2015 ecsos@opensuse.org
- update to 1.0.2
  - Fixed modulus zero exception in password generation #102
  - Installation prefix selection #100
  - Made IP urls clickable by simplifying regex #97
  - Added trailing newline if missing #93
* Tue Aug 11 2015 ecsos@opensuse.org
- update to 1.0.1
  - Correct focussing of filter input #89
  - Templates for password input
  - Show password title in in input window
  - Clear the text field(s) after X seconds #86
  - User list look and colour scheme #82
  - Auto push/pull options for git #83
  - Commit deletes to git #81
  - Git init of repositories #72
  - Yubikey Neo linux info added to FAQ #73
* Wed Aug  5 2015 ecsos@opensuse.org
- update to 1.0.0
  - Chinese translations
  - Hungarian translations
  - German translations
* Fri Jul 31 2015 ecsos@opensuse.org
- update to 0.9.2
  - Filter expired keys and show creation and expiry date of
    keys #70
  - Fixed stupid sigsev on empty profile names found by @sigio
  - Minor tweaks for usability
- changes from 0.9.1
  - pwgen and git options not available when not applicable
  - git removal of files (when applicable) #57
  - filtering of unusable keys in user dialog
* Sun Jul 19 2015 ecsos@opensuse.org
- update to 0.9.0
  - Fixed first run order issues
  - Dutch translation updated
  - Interface margins redefined
- changes from 0.8.6
  - Now compiling with older C++ compilers
    (removed C++11 dependency)
  - Now working with Qt 4.4+ (removed Qt 5.2 dependency)
  - pwgen integration #68
  - minor clipboard related fix
* Mon Jul 13 2015 ecsos@opensuse.org
- initial version 0.8.5.1
